#### Manuscript: OIK-10433
#### Title: Risk response towards roads is consistent across multiple species
##          in a temperate forest ecosystem
#### Date (creation): 12/2023
#### Date (last update): 01/2024
#### Purpose: Perform correlation plots (Supporting information 3)


#### Load packages ####
library(dplyr)
library(purrr)
library(ggpubr)
library(ggcorrplot)


#### Load functions####

## Function to create correlation plots
CorrPlot <- function(data, step="both") {
  
  ##### start and end of the step
  if (step=="both") {
    
  var <- data %>% dplyr::select(c(log_sl, cos_ta,
                                   log_dist_road_start, log_dist_road_end,
                                   crossings,
                                   cover_end, understory_end, ruggedness_end,
                                   night_suncalc_start, night_suncalc_end,
                                   twilight_suncalc_start, twilight_suncalc_end,
                                   season_start, season_end))
  
  cor <- round(cor(na.omit(var), method = "spearman"), 1)
  
  colnames(cor) <- c(
    "log_sl" = "Step length (ln)", "ta_" = "Turning angle",
    "log_dist_road_start" = "Distance to Road start", "log_dist_road_end" = "Distance to Road end",
    "crossings" = "Road Crossing",
    "cover_end" = "Canopy Cover end",
    "understory_end" = "Understorey end",
    "ruggedness_end" ="Ruggedness end",
    "night_suncalc_start" = "Night start", "night_suncalc_end" = "Night end",
    "twilight_suncalc_start" = "Twilight start", "twilight_suncalc_end" = "Twilight end",
    "start" = "Season start", "season_end" = "Season end")
  
  rownames(cor) <- c(
    "log_sl" = "Step length (ln)", "ta_" = "Turning angle",
    "log_dist_road_start" = "Distance to Road start", "log_dist_road_end" = "Distance to Road end",
    "crossings" = "Road Crossing",
    "cover_end" = "Canopy Cover end",
    "understory_end" = "Understorey end",
    "ruggedness_end" ="Ruggedness end",
    "night_suncalc_start" = "Night start", "night_suncalc_end" = "Night end",
    "twilight_suncalc_start" = "Twilight start", "twilight_suncalc_end" = "Twilight end",
    "start" = "Season start", "season_end" = "Season end")
  
  ## with package corrplot
  # corplot <- corrplot(cor, method="number", type="upper",
  #                     number.cex = 0.7, tl.cex = 0.7, tl.col="black",
  #                     title=unique(data[, "name"]))
  
  ## with package ggcorrplot
  corplot <- ggcorrplot(cor,
                        hc.order = FALSE,
                        type = "lower",
                        lab = TRUE,
                        colors = c("#6D9EC1", "white", "#E46726"),
                        title=unique(data[, "name"]),
                        tl.cex = 12,
                        lab_size = 3,
                        show.diag=TRUE)
  
  
  #### only end of the step
  } else if(step=="end") {
    
  var <- data %>% dplyr::select(c(log_sl, cos_ta,
                                  log_dist_road_end,
                                  crossings,
                                  cover_end,
                                  understory_end,
                                  ruggedness_end,
                                  night_suncalc_end,
                                  twilight_suncalc_end,
                                  season_end))
  
  cor <- round(cor(na.omit(var), method = "spearman"), 1)
  
  colnames(cor) <- c(
    "log_sl" = "Step length (ln)", "ta_" = "Turning angle",
    "log_dist_road_end" = "Distance to Road end",
    "crossings" = "Road Crossing",
    "cover_end" = "Canopy Cover end",
    "understory_end" = "Understorey end",
    "ruggedness_end" ="Ruggedness end",
    "night_suncalc_end" = "Night end",
    "twilight_suncalc_end" = "Twilight end",
    "season_end" = "Season end")
  
  rownames(cor) <- c(
    "log_sl" = "Step length (ln)", "ta_" = "Turning angle",
    "log_dist_road_end" = "Distance to Road end",
    "crossings" = "Road Crossing",
    "cover_end" = "Canopy Cover end",
    "understory_end" = "Understorey end",
    "ruggedness_end" ="Ruggedness end",
    "night_suncalc_end" = "Night end",
    "twilight_suncalc_end" = "Twilight end",
    "season_end" = "Season end")
  
  ## with package corrplot
  # corplot <- corrplot(cor, method="number", type="upper",
  #                     number.cex = 0.7, tl.cex = 0.7, tl.col="black",
  #                     title=unique(data[, "name"]))
  
  ## with package ggcorrplot
  corplot <- ggcorrplot(cor,
                        hc.order = FALSE,
                        type = "lower",
                        lab = TRUE,
                        colors = c("#6D9EC1", "white", "#E46726"),
                        title=unique(data[, "name"]),
                        tl.cex = 12,
                        lab_size = 3,
                        show.diag=TRUE)
  
  }
  
  return(corplot)
  
}


#### Load data ####

data_path <- " " #add the path to your data (e.g. "C:/Users/username/Downloads/")

## Lynx
lynxtrk_ssf_1h <- readRDS(paste0(data_path, "data/lynx_1_x_hour.rds"))
lynxtrk_ssf_1h$name <- "Lynx"
## Wild boar
boartrk_ssf_f <- readRDS(paste0(data_path, "data/wild_boar_females.rds"))
boartrk_ssf_f$name <- "Wild boar females"
boartrk_ssf_m <- readRDS(paste0(data_path, "data/wild_boar_males.rds"))
boartrk_ssf_m$name <- "Wild boar males"
## Roe deer
roetrk_ssf_f <- readRDS(paste0(data_path, "data/roe_deer_females.rds"))
roetrk_ssf_f$name <- "Roe deer females"
roetrk_ssf_m <- readRDS(paste0(data_path, "data/roe_deer_males.rds"))
roetrk_ssf_m$name <- "Roe deer males"
## Red deer
redtrk_ssf_f <- readRDS(paste0(data_path, "data/red_deer_females.rds"))
redtrk_ssf_f$name <- "Red deer females"
redtrk_ssf_m <- readRDS(paste0(data_path, "data/red_deer_males.rds"))
redtrk_ssf_m$name <- "Red deer males"

data_ls <- list(lynx_1h=lynxtrk_ssf_1h,
                wild_boar_females=boartrk_ssf_f,
                wild_boar_males=boartrk_ssf_m,
                roe_deer_females=roetrk_ssf_f,
                roe_deer_males=roetrk_ssf_m,
                red_deer_females=redtrk_ssf_f,
                red_deer_males=redtrk_ssf_m)


#### Supporting information 3 ####

##### Figure S3 ####

corplot_ls <- map(data_ls, function(x) CorrPlot(x))

corplot_lynx <- ggarrange(corplot_ls$lynx_1h, ncol=2, common.legend = TRUE)
corplot_boar <- ggarrange(plotlist=list(corplot_ls$wild_boar_females, corplot_ls$wild_boar_males), common.legend = TRUE)
corplot_roe <- ggarrange(plotlist=list(corplot_ls$roe_deer_females, corplot_ls$roe_deer_males), common.legend = TRUE)
corplot_red <- ggarrange(plotlist=list(corplot_ls$red_deer_females, corplot_ls$red_deer_males), common.legend = TRUE)

corplot_arr_ls <- list(
  lynx=corplot_lynx,
  boar=corplot_boar,
  roe=corplot_roe,
  red=corplot_red)

# for(i in 1:length(corplot_arr_ls)) {
#   ggsave(filename=paste0("corrplot_", names(corplot_arr_ls[i]), ".tiff"),
#          plot=corplot_arr_ls[[i]], device="tiff",
#          width=30, heigh=20,
#          units="cm", dpi=500,
#          path=data_path, bg="white")
# }

